:mod:`pyvex` --- Binary Translator
==================================

.. automodule:: pyvex
.. automodule:: pyvex.native


Translation Interface
---------------------

.. automodule:: pyvex.block


IR Components
-------------

.. automodule:: pyvex.stmt
.. automodule:: pyvex.expr
.. automodule:: pyvex.const
.. automodule:: pyvex.enums

Lifting System
--------------

.. automodule:: pyvex.data_ref
.. automodule:: pyvex.lifting
.. automodule:: pyvex.lifting.lift_function
.. automodule:: pyvex.lifting.libvex
.. automodule:: pyvex.lifting.lifter
.. automodule:: pyvex.lifting.post_processor
.. automodule:: pyvex.lifting.util.irsb_postprocess
.. automodule:: pyvex.lifting.util
.. automodule:: pyvex.lifting.util.syntax_wrapper
.. automodule:: pyvex.lifting.util.vex_helper
.. automodule:: pyvex.lifting.util.lifter_helper
.. automodule:: pyvex.lifting.util.instr_helper

Builtin IR Processors
---------------------

.. automodule:: pyvex.lifting.zerodivision

Errors
------

.. automodule:: pyvex.errors

Utilities
---------

.. automodule:: pyvex.utils
